==> tabular-data-template-1.3.1-20140627.100902-3-sources.jar: org/gcube/portlets/user/tdtemplate/client/rpc/TdTemplateServiceAsync.java <==
package org.gcube.portlets.user.tdtemplate.client.rpc;

import java.util.List;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.tdtemplate.shared.ClientReportTemplateSaved;
import org.gcube.portlets.user.tdtemplate.shared.TdColumnDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateUpdater;
import org.gcube.portlets.user.tdtemplate.shared.validator.ViolationDescription;

import com.google.gwt.user.client.rpc.AsyncCallback;

public interface TdTemplateServiceAsync{

	void getTemplateTypes(AsyncCallback<List<TdTTemplateType>> callback);

	void submitTemplate(List<TdColumnDefinition> listColumns,
			AsyncCallback<ClientReportTemplateSaved> callback);

	/**
	 * @param def
	 * @param callback
	 */
	void getColumnCategoryByTdTemplateDefinition(TdTemplateDefinition def,
			AsyncCallback<List<TdTColumnCategory>> callback);

	void getOnErrorValues(AsyncCallback<List<String>> callback);

	void getConstraintForTemplateType(TdTTemplateType type,
			AsyncCallback<String> callback);

	void resolveColumnForDimension(TRId trId,
			AsyncCallback<List<ColumnData>> callback);

	void getTemplateUpdaterForTemplateId(long templateId,
			AsyncCallback<TdTemplateUpdater> callback);

	void updateTemplate(List<TdColumnDefinition> listColumns,
			AsyncCallback<ClientReportTemplateSaved> callback);

	void getAllowedLocales(AsyncCallback<List<String>> callback);

	void isValidTemplate(List<TdTColumnCategory> columns,
			AsyncCallback<Boolean> callback);

	void getTemplateConstraintsViolations(
			AsyncCallback<List<ViolationDescription>> callback);

	void getTemplateHelper(AsyncCallback<String> callback);

	void getTimeDimensionPeriodTypes(AsyncCallback<List<String>> callback);

	
}

==> tabular-data-template-1.4.0-20141210.114322-9-sources.jar: org/gcube/portlets/user/tdtemplate/client/rpc/TdTemplateServiceAsync.java <==
package org.gcube.portlets.user.tdtemplate.client.rpc;

import java.util.List;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.tdtemplate.shared.ClientReportTemplateSaved;
import org.gcube.portlets.user.tdtemplate.shared.TdBehaviourModel;
import org.gcube.portlets.user.tdtemplate.shared.TdColumnDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdFlowModel;
import org.gcube.portlets.user.tdtemplate.shared.TdLicenceModel;
import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateUpdater;
import org.gcube.portlets.user.tdtemplate.shared.validator.ViolationDescription;

import com.google.gwt.user.client.rpc.AsyncCallback;

public interface TdTemplateServiceAsync{

	void getTemplateTypes(AsyncCallback<List<TdTTemplateType>> callback);

	void submitTemplate(List<TdColumnDefinition> listColumns,
			TdFlowModel flowAttached, AsyncCallback<ClientReportTemplateSaved> callback);

	/**
	 * @param def
	 * @param callback
	 */
	void getColumnCategoryByTdTemplateDefinition(TdTemplateDefinition def,
			AsyncCallback<List<TdTColumnCategory>> callback);

	void getOnErrorValues(AsyncCallback<List<String>> callback);

	void getConstraintForTemplateType(TdTTemplateType type,
			AsyncCallback<String> callback);

	void resolveColumnForDimension(TRId trId,
			AsyncCallback<List<ColumnData>> callback);

	void getTemplateUpdaterForTemplateId(long templateId,
			AsyncCallback<TdTemplateUpdater> callback);

	void updateTemplate(List<TdColumnDefinition> listColumns,
			AsyncCallback<ClientReportTemplateSaved> callback);

	void getAllowedLocales(AsyncCallback<List<String>> callback);

	void isValidTemplate(List<TdTColumnCategory> columns,
			AsyncCallback<Boolean> callback);

	void getTemplateConstraintsViolations(
			AsyncCallback<List<ViolationDescription>> callback);

	void getTemplateHelper(AsyncCallback<String> callback);

	void getTimeDimensionPeriodTypes(AsyncCallback<List<String>> callback);

	void getLicences(AsyncCallback<List<TdLicenceModel>> callback);
	
	void getBehaviours(AsyncCallback<List<TdBehaviourModel>> callback);
	
	void getFlowByTemplateId(long templateId, AsyncCallback<TdFlowModel> flow);
}
